Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(597)

Unified Diff: include/dart_api.h

Issue 11280241: Fix StringBase_createFromCodePoints to correctly accept Latin-1 characters (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | lib/string.cc » ('j') | vm/dart_api_impl_test.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/dart_api.h
===================================================================
--- include/dart_api.h (revision 15534)
+++ include/dart_api.h (working copy)
@@ -1425,10 +1425,10 @@
void** peer);
/**
- * Returns a String which references an external array of UTF-8 encoded
- * characters.
+ * Returns a String which references an external array of
+ * Latin-1 (ISO-8859-1) encoded characters.
*
* \param utf8_array An array of UTF-8 encoded characters. This must not move.
* \param length The length of the characters array.
* \param peer An external pointer to associate with this string.
* \param cback A callback to be called when this string is finalized.
@@ -1436,10 +1436,11 @@
* \return The String object if no error occurs. Otherwise returns
* an error handle.
*/
-DART_EXPORT Dart_Handle Dart_NewExternalUTF8String(const uint8_t* utf8_array,
- intptr_t length,
- void* peer,
- Dart_PeerFinalizer cback);
+DART_EXPORT Dart_Handle Dart_NewExternalLatin1String(
+ const uint8_t* latin1_array,
+ intptr_t length,
+ void* peer,
+ Dart_PeerFinalizer cback);
/**
* Returns a String which references an external array of UTF-16 encoded
« no previous file with comments | « no previous file | lib/string.cc » ('j') | vm/dart_api_impl_test.cc » ('J')
@@ -1425,10 +1425,10 @@
*
- * \param utf8_array An array of UTF-8 encoded characters. This must not move.
+ * \param latin1_array Array of Latin-1 encoded characters. This must not move.
* \param length The length of the characters array.
* \param peer An external pointer to associate with this string.

Powered by Google App Engine
This is Rietveld 408576698